/**
 * @license
 * SPDX-License-Identifier: Apache-2.0
 */
import '../environment/dev.js';
import { SafeHtml } from '../internals/html_impl.js';
/**
 * Creates a DocumentFragment object from a template literal (without any
 * embedded expressions) using the document context (HTML).
 *
 * Note: use svgFragment instead to create a DocumentFragment belonging to the
 * SVG namespace.
 *
 * This function is a template literal tag function. It should be called with
 * a template literal that does not contain any expressions. For example,
 *                           htmlFragment`foo`;
 *
 * @param templateObj This contains the literal part of the template literal.
 */
export declare function htmlFragment(templateObj: TemplateStringsArray): DocumentFragment;
/**
 * Creates a DocumentFragment object from a template literal (without any
 * embedded expressions), with an SVG context.
 *
 * This function is a template literal tag function. It should be called with
 * a template literal that does not contain any expressions. For example,
 *                           svgFragment`foo`;
 *
 * @param templateObj This contains the literal part of the template literal.
 */
export declare function svgFragment(templateObj: TemplateStringsArray): DocumentFragment;
/** Converts HTML markup into a node. */
export declare function htmlToNode(html: SafeHtml): Node;
